@@ -1,9 +1,10 @@
-from .core import (
+from .scipy import (
+    ks_1samp_1d,
     ks_2samp_1d,
-    ks_2samp_2d,
     anderson_ksamp,
     ttest_ind,
     ttest_rel,
+    cramervonmises,
     cramervonmises_2samp,
     epps_singleton_2samp,
     mannwhitneyu,
@@ -17,6 +18,14 @@ from .core import (
     fligner,
     median_test,
     mood,
+    skewtest,
+    kurtosistest,
+    normaltest,
+    jarque_bera,
+    shapiro,
+)
+from .core import (
+    ks_2samp_2d,
 )
 
 from . import _version
